begining->beginning
dirve->drive
duplicat->duplicate
fuly->fully
Funciton->Function
Functino->Function
optioanl->optional
poitners->pointers
rountine->routine
sucessful->successful
sucessfully->successfully

Signed-off-by: Page Chen <paiching_c...@apple.com>
Cc: Zhichao Gao <zhichao....@intel.com>
Cc: Andrew Fish <af...@apple.com>
---
 .../HttpDynamicCommand/HttpApp.c              |  2 +-
 .../HttpDynamicCommand/HttpDynamicCommand.c   |  4 +-
 ShellPkg/Include/Library/BcfgCommandLib.h     |  2 +-
 ShellPkg/Include/Library/HandleParsingLib.h   |  2 +-
 ShellPkg/Include/Library/ShellCommandLib.h    |  6 +--
 ShellPkg/Include/Library/ShellLib.h           | 30 +++++++-------
 .../Include/Protocol/EfiShellEnvironment2.h   | 10 ++---
 .../UefiHandleParsingLib.c                    | 16 ++++----
 .../UefiShellBcfgCommandLib.c                 | 20 +++++-----
 .../UefiShellCommandLib/UefiShellCommandLib.c |  6 +--
 .../UefiShellDebug1CommandsLib/Compress.c     |  2 +-
 .../UefiShellDebug1CommandsLib/Compress.h     |  2 +-
 .../UefiShellDebug1CommandsLib.c              |  2 +-
 .../UefiShellDriver1CommandsLib.c             |  2 +-
 .../UefiShellInstall1CommandsLib.c            |  2 +-
 .../UefiShellLevel1CommandsLib.c              |  4 +-
 .../UefiShellLevel1CommandsLib.h              |  2 +-
 .../Library/UefiShellLevel2CommandsLib/Cd.c   |  4 +-
 .../Library/UefiShellLevel2CommandsLib/Ls.c   |  2 +-
 .../Library/UefiShellLevel2CommandsLib/Map.c  |  2 +-
 .../Library/UefiShellLevel2CommandsLib/Mv.c   |  6 +--
 .../Library/UefiShellLevel2CommandsLib/Set.c  |  2 +-
 .../UefiShellLevel2CommandsLib.c              |  8 ++--
 .../UefiShellLevel2CommandsLib.h              |  6 +--
 .../Library/UefiShellLevel2CommandsLib/Vol.c  |  2 +-
 .../UefiShellLevel3CommandsLib/Alias.c        |  4 +-
 .../UefiShellLevel3CommandsLib/Touch.c        |  4 +-
 .../Library/UefiShellLevel3CommandsLib/Type.c |  4 +-
 .../UefiShellLevel3CommandsLib.c              |  2 +-
 ShellPkg/Library/UefiShellLib/UefiShellLib.c  | 40 +++++++++----------
 .../UefiShellNetwork1CommandsLib/Ping.c       |  2 +-
 .../UefiShellNetwork1CommandsLib.c            |  2 +-
 .../UefiShellNetwork2CommandsLib/Ping6.c      |  2 +-
 .../UefiShellNetwork2CommandsLib.c            |  2 +-
 34 files changed, 104 insertions(+), 104 deletions(-)

diff --git a/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpApp.c 
b/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpApp.c
index 6622e058aab6..ea41417fc3d6 100644
--- a/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpApp.c
+++ b/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpApp.c
@@ -28,7 +28,7 @@ EFI_STRING_ID  mStringHelpTokenId = STRING_TOKEN 
(STR_GET_HELP_HTTP);
   @param ImageHandle            The image handle of the process.
   @param SystemTable            The EFI System Table pointer.
 
-  @retval EFI_SUCCESS           Http command is executed sucessfully.
+  @retval EFI_SUCCESS           Http command is executed successfully.
   @retval EFI_ABORTED           HII package was failed to initialize.
   @retval others                Other errors when executing http command.
 **/
diff --git a/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpDynamicCommand.c 
b/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpDynamicCommand.c
index 45aeaac347ad..d3c384dc8b8a 100644
--- a/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpDynamicCommand.c
+++ b/ShellPkg/DynamicCommand/HttpDynamicCommand/HttpDynamicCommand.c
@@ -22,7 +22,7 @@
   @param[in] Shell              The instance of the shell protocol used in
                                 the context of processing this command.
 
-  @return EFI_SUCCESS           the operation was sucessful
+  @return EFI_SUCCESS           the operation was successful
   @return other                 the operation failed.
 **/
 SHELL_STATUS
@@ -78,7 +78,7 @@ EFI_SHELL_DYNAMIC_COMMAND_PROTOCOL  mHttpDynamicCommand = {
   @param ImageHandle            The image handle of the process.
   @param SystemTable            The EFI System Table pointer.
 
-  @retval EFI_SUCCESS           Http command is executed sucessfully.
+  @retval EFI_SUCCESS           Http command is executed successfully.
   @retval EFI_ABORTED           HII package was failed to initialize.
   @retval others                Other errors when executing http command.
 **/
diff --git a/ShellPkg/Include/Library/BcfgCommandLib.h 
b/ShellPkg/Include/Library/BcfgCommandLib.h
index ec5579ce614a..649fe00f98a2 100644
--- a/ShellPkg/Include/Library/BcfgCommandLib.h
+++ b/ShellPkg/Include/Library/BcfgCommandLib.h
@@ -18,7 +18,7 @@
   @param[in] SystemTable    the EFI System Table pointer
   @param[in] Name           the profile name to use
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
diff --git a/ShellPkg/Include/Library/HandleParsingLib.h 
b/ShellPkg/Include/Library/HandleParsingLib.h
index 8193be94a478..b86d69cb0ef5 100644
--- a/ShellPkg/Include/Library/HandleParsingLib.h
+++ b/ShellPkg/Include/Library/HandleParsingLib.h
@@ -20,7 +20,7 @@
   @param[in] TheName    The Guid's name
   @param[in] Lang       RFC4646 language code list or NULL
 
-  @retval EFI_SUCCESS           The operation was sucessful
+  @retval EFI_SUCCESS           The operation was successful
   @retval EFI_ACCESS_DENIED     There was a duplicate
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed
 **/
diff --git a/ShellPkg/Include/Library/ShellCommandLib.h 
b/ShellPkg/Include/Library/ShellCommandLib.h
index 7a97b203f1ff..0b185e3e5781 100644
--- a/ShellPkg/Include/Library/ShellCommandLib.h
+++ b/ShellPkg/Include/Library/ShellCommandLib.h
@@ -70,7 +70,7 @@ CONST CHAR16 *
                                       the command built into shell.
   @param[in] SystemTable              The pointer to the system table.
 
-  @retval  RETURN_SUCCESS             The shell command was sucessful.
+  @retval  RETURN_SUCCESS             The shell command was successful.
   @retval  RETURN_UNSUPPORTED         The command is not supported.
 **/
 typedef
@@ -544,7 +544,7 @@ ShellCommandFindMapItem (
   @param[in] Flags              The Flags attribute for this map item.
   @param[in] Path               TRUE to update path, FALSE to skip this step 
(should only be TRUE during initialization).
 
-  @retval EFI_SUCCESS           The addition was sucessful.
+  @retval EFI_SUCCESS           The addition was successful.
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed.
   @retval EFI_INVALID_PARAMETER A parameter was invalid.
 **/
@@ -563,7 +563,7 @@ ShellCommandAddMapItemAndUpdatePath (
 
   Also sets up the default path environment variable if Type is FileSystem.
 
-  @retval EFI_SUCCESS           All map names were created sucessfully.
+  @retval EFI_SUCCESS           All map names were created successfully.
   @retval EFI_NOT_FOUND         No protocols were found in the system.
   @return                       Error returned from gBS->LocateHandle().
 
diff --git a/ShellPkg/Include/Library/ShellLib.h 
b/ShellPkg/Include/Library/ShellLib.h
index 10cf7f4fefe0..f41bc4851c57 100644
--- a/ShellPkg/Include/Library/ShellLib.h
+++ b/ShellPkg/Include/Library/ShellLib.h
@@ -300,7 +300,7 @@ ShellWriteFile (
 
   @param[in] FileHandle           The file handle to close.
 
-  @retval EFI_SUCCESS             The file handle was closed sucessfully.
+  @retval EFI_SUCCESS             The file handle was closed successfully.
   @retval INVALID_PARAMETER       One of the parameters has an invalid value.
 **/
 EFI_STATUS
@@ -318,7 +318,7 @@ ShellCloseFile (
 
   @param[in] FileHandle             The file handle to delete.
 
-  @retval EFI_SUCCESS               The file was closed sucessfully.
+  @retval EFI_SUCCESS               The file was closed successfully.
   @retval EFI_WARN_DELETE_FAILURE   The handle was closed, but the file was not
                                     deleted.
   @retval INVALID_PARAMETER         One of the parameters has an invalid value.
@@ -342,9 +342,9 @@ ShellDeleteFile (
 
   @param[in] FileHandle         The file handle on which the position is being 
set.
 
-  @param[in] Position           The byte position from the begining of the 
file.
+  @param[in] Position           The byte position from the beginning of the 
file.
 
-  @retval EFI_SUCCESS           Operation completed sucessfully.
+  @retval EFI_SUCCESS           Operation completed successfully.
   @retval EFI_UNSUPPORTED       The seek request for non-zero is not valid on
                                 directories.
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
@@ -365,9 +365,9 @@ ShellSetFilePosition (
   if FileHandle is a directory.
 
   @param[in] FileHandle         The open file handle on which to get the 
position.
-  @param[out] Position          The byte position from the begining of the 
file.
+  @param[out] Position          The byte position from the beginning of the 
file.
 
-  @retval EFI_SUCCESS           The operation completed sucessfully.
+  @retval EFI_SUCCESS           The operation completed successfully.
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
   @retval EFI_UNSUPPORTED       The request is not valid on directories.
 **/
@@ -466,7 +466,7 @@ ShellFindNextFile (
   @param[in] FileHandle         The file handle from which size is retrieved.
   @param[out] Size              The pointer to size.
 
-  @retval EFI_SUCCESS           The operation was completed sucessfully.
+  @retval EFI_SUCCESS           The operation was completed successfully.
   @retval EFI_DEVICE_ERROR      Cannot access the file.
 **/
 EFI_STATUS
@@ -524,7 +524,7 @@ ShellGetEnvironmentVariable (
   @param[in] EnvVal             The Value of the environment variable
   @param[in] Volatile           Indicates whether the variable is non-volatile 
(FALSE) or volatile (TRUE).
 
-  @retval EFI_SUCCESS           The operation completed sucessfully
+  @retval EFI_SUCCESS           The operation completed successfully
   @retval EFI_UNSUPPORTED       This operation is not allowed in pre-UEFI 2.0 
Shell environments.
 **/
 EFI_STATUS
@@ -559,7 +559,7 @@ ShellSetEnvironmentVariable (
                                   in the form "x=y".  If NULL, the current set 
is used.
   @param[out] Status              The status of the run command line.
 
-  @retval EFI_SUCCESS             The operation completed sucessfully.  Status
+  @retval EFI_SUCCESS             The operation completed successfully.  Status
                                   contains the status code returned.
   @retval EFI_INVALID_PARAMETER   A parameter contains an invalid value.
   @retval EFI_OUT_OF_RESOURCES    Out of resources.
@@ -626,7 +626,7 @@ ShellSetPageBreakMode (
   @param[in] OpenMode            Mode to open files with.
   @param[in, out] ListHead       Head of linked list of results.
 
-  @retval EFI_SUCCESS           The operation was sucessful and the list head
+  @retval EFI_SUCCESS           The operation was successful and the list head
                                 contains the list of opened files.
   @retval != EFI_SUCCESS        The operation failed.
 
@@ -645,7 +645,7 @@ ShellOpenFileMetaArg (
 
   @param[in, out] ListHead       The pointer to free.
 
-  @retval EFI_SUCCESS           The operation was sucessful.
+  @retval EFI_SUCCESS           The operation was successful.
   @retval EFI_INVALID_PARAMETER A parameter was invalid.
 **/
 EFI_STATUS
@@ -730,7 +730,7 @@ extern SHELL_PARAM_ITEM  SfoParamList[];
   @param[in] AutoPageBreak      Will automatically set PageBreakEnabled.
   @param[in] AlwaysAllowNumbers Will never fail for number based flags.
 
-  @retval EFI_SUCCESS           The operation completed sucessfully.
+  @retval EFI_SUCCESS           The operation completed successfully.
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed.
   @retval EFI_INVALID_PARAMETER A parameter was invalid.
   @retval EFI_VOLUME_CORRUPTED  The command line was corrupt.
@@ -878,7 +878,7 @@ ShellCommandLineCheckDuplicate (
 
   This function is intended for internal access for shell commands only.
 
-  @retval EFI_SUCCESS   The initialization was complete sucessfully.
+  @retval EFI_SUCCESS   The initialization was complete successfully.
 
 **/
 EFI_STATUS
@@ -1249,7 +1249,7 @@ ShellPromptForResponse (
   @param[in] HiiFormatHandle     The format string Handle for getting from Hii.
   @param[in, out] Response       The pointer to Response, which will be 
populated upon return.
 
-  @retval EFI_SUCCESS The operation was sucessful.
+  @retval EFI_SUCCESS The operation was successful.
   @return other       The operation failed.
 
   @sa ShellPromptForResponse
@@ -1385,7 +1385,7 @@ ShellFileHandleReadLine (
 
   @param[in]       FileName       Pointer to file name to delete.
 
-  @retval EFI_SUCCESS             the file was deleted sucessfully
+  @retval EFI_SUCCESS             the file was deleted successfully
   @retval EFI_WARN_DELETE_FAILURE the handle was closed, but the file was not
                                   deleted
   @retval EFI_INVALID_PARAMETER   One of the parameters has an invalid value.
diff --git a/ShellPkg/Include/Protocol/EfiShellEnvironment2.h 
b/ShellPkg/Include/Protocol/EfiShellEnvironment2.h
index 8b7c86dc24fc..2f826be070fa 100644
--- a/ShellPkg/Include/Protocol/EfiShellEnvironment2.h
+++ b/ShellPkg/Include/Protocol/EfiShellEnvironment2.h
@@ -507,7 +507,7 @@ VOID
   This must be called after INIT_HANDLE_ENUMERATOR and before 
CLOSE_HANDLE_ENUMERATOR.
 
   @param[in, out] Handle         The pointer to pointer to Handle.  It is set
-                                 on a sucessful return.
+                                 on a successful return.
 
   @retval EFI_SUCCESS           The next handle in the handle database is 
*Handle.
   @retval EFI_NOT_FOUND         There is not another handle.
@@ -652,7 +652,7 @@ VOID
 
   @param[in, out] ProtocolInfo   The pointer to pointer to protocol 
information structure.
 
-  @retval EFI_SUCCESS           The next protocol's information was 
sucessfully returned.
+  @retval EFI_SUCCESS           The next protocol's information was 
successfully returned.
   @retval NULL                  There are no more protocols.
 **/
 typedef
@@ -684,7 +684,7 @@ EFI_STATUS
   called after INIT_PROTOCOL_INFO_ENUMERATOR.
 
   This function resets the list of protocols such that the next one in the
-  list is the begining of the list.
+  list is the beginning of the list.
 **/
 typedef
 VOID
@@ -809,7 +809,7 @@ EFI_DEVICE_PATH_PROTOCOL *
 
   This function looks through the shell environment map for a map whose device
   path matches the DevPath parameter.  If one is found the Name is returned via
-  Name parameter.  If sucessful the caller must free the memory allocated for
+  Name parameter.  If successful the caller must free the memory allocated for
   Name.
 
   This function will use the internal lock to prevent changes to the map during
@@ -817,7 +817,7 @@ EFI_DEVICE_PATH_PROTOCOL *
 
   @param[in] DevPath                The device path to search for a name for.
   @param[in] ConsistMapping         What state to verify map flag 
VAR_ID_CONSIST.
-  @param[out] Name                  On sucessful return the name of that 
device path.
+  @param[out] Name                  On successful return the name of that 
device path.
 
   @retval EFI_SUCCESS           The DevPath was found and the name returned
                                 in Name.
diff --git a/ShellPkg/Library/UefiHandleParsingLib/UefiHandleParsingLib.c 
b/ShellPkg/Library/UefiHandleParsingLib/UefiHandleParsingLib.c
index aa0115bdd498..781da4d55d96 100644
--- a/ShellPkg/Library/UefiHandleParsingLib/UefiHandleParsingLib.c
+++ b/ShellPkg/Library/UefiHandleParsingLib/UefiHandleParsingLib.c
@@ -2549,7 +2549,7 @@ Function to add a new GUID/Name mapping.
 @param[in] DumpFunc   The pointer to the dump function
 
 
-@retval EFI_SUCCESS           The operation was sucessful
+@retval EFI_SUCCESS           The operation was successful
 @retval EFI_OUT_OF_RESOURCES  A memory allocation failed
 @retval EFI_INVALID_PARAMETER Guid NameId was invalid
 **/
@@ -2595,7 +2595,7 @@ InsertNewGuidNameMapping (
   @param[in] TheName    The Guid's name
   @param[in] Lang       RFC4646 language code list or NULL
 
-  @retval EFI_SUCCESS           The operation was sucessful
+  @retval EFI_SUCCESS           The operation was successful
   @retval EFI_ACCESS_DENIED     There was a duplicate
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed
   @retval EFI_INVALID_PARAMETER Guid or TheName was NULL
@@ -2708,7 +2708,7 @@ GetProtocolInformationDump (
   @param[in] Lang           The pointer to the language code.
   @param[out] Guid          The pointer to the Guid.
 
-  @retval EFI_SUCCESS       The operation was sucessful.
+  @retval EFI_SUCCESS       The operation was successful.
 **/
 EFI_STATUS
 EFIAPI
@@ -3312,7 +3312,7 @@ ParseHandleDatabaseByRelationshipWithType (
   If both DriverBindingHandle and ControllerHandle are NULL, then ASSERT.
   If MatchingHandleCount is NULL, then ASSERT.
 
-  If MatchingHandleBuffer is not NULL upon a sucessful return the memory must 
be
+  If MatchingHandleBuffer is not NULL upon a successful return the memory must 
be
   caller freed.
 
   @param[in] DriverBindingHandle    Handle to a object with Driver Binding 
protocol
@@ -3321,10 +3321,10 @@ ParseHandleDatabaseByRelationshipWithType (
   @param[in] Mask                   Mask of what relationship(s) is desired.
   @param[in] MatchingHandleCount    Poitner to UINTN specifying number of 
HANDLES in
                                     MatchingHandleBuffer.
-  @param[out] MatchingHandleBuffer  On a sucessful return a buffer of 
MatchingHandleCount
+  @param[out] MatchingHandleBuffer  On a successful return a buffer of 
MatchingHandleCount
                                     EFI_HANDLEs and a terminating NULL 
EFI_HANDLE.
 
-  @retval EFI_SUCCESS               The operation was sucessful and any 
related handles
+  @retval EFI_SUCCESS               The operation was successful and any 
related handles
                                     are in MatchingHandleBuffer;
   @retval EFI_NOT_FOUND             No matching handles were found.
   @retval EFI_INVALID_PARAMETER     A parameter was invalid or out of range.
@@ -3450,7 +3450,7 @@ ParseHandleDatabaseByRelationship (
                                     return.
 
 
-  @retval EFI_SUCCESS               The operation was sucessful.
+  @retval EFI_SUCCESS               The operation was successful.
 **/
 EFI_STATUS
 EFIAPI
@@ -3613,7 +3613,7 @@ BuffernCatGrow (
                                     MatchingHandleBuffer on return.
   @param[out] MatchingHandleBuffer  Buffer containing handles on a successful
                                     return.
-  @retval EFI_SUCCESS               The operation was sucessful.
+  @retval EFI_SUCCESS               The operation was successful.
   @sa ParseHandleDatabaseByRelationship
 **/
 EFI_STATUS
diff --git a/ShellPkg/Library/UefiShellBcfgCommandLib/UefiShellBcfgCommandLib.c 
b/ShellPkg/Library/UefiShellBcfgCommandLib/UefiShellBcfgCommandLib.c
index 4a19794b9fe0..0b94d9f5a183 100644
--- a/ShellPkg/Library/UefiShellBcfgCommandLib/UefiShellBcfgCommandLib.c
+++ b/ShellPkg/Library/UefiShellBcfgCommandLib/UefiShellBcfgCommandLib.c
@@ -79,10 +79,10 @@ typedef struct {
 
   @param[in]      Index     The boot or driver option index update.
   @param[in]      DataSize  The size in bytes of Data.
-  @param[in]      Data      The buffer for the optioanl data.
+  @param[in]      Data      The buffer for the optional data.
   @param[in]      Target    The target of the operation.
 
-  @retval EFI_SUCCESS       The data was sucessfully updated.
+  @retval EFI_SUCCESS       The data was successfully updated.
   @retval other             A error occurred.
 **/
 EFI_STATUS
@@ -172,7 +172,7 @@ UpdateOptionalData (
   @param[in, out] Crc         The CRC value to return.
   @param[in]      BootIndex   The boot option index to CRC.
 
-  @retval EFI_SUCCESS           The CRC was sucessfully returned.
+  @retval EFI_SUCCESS           The CRC was successfully returned.
   @retval other                 A error occurred.
 **/
 EFI_STATUS
@@ -226,9 +226,9 @@ GetBootOptionCrc (
   This function will populate the device path protocol parameter based on 
TheHandle.
 
   @param[in]      TheHandle     Driver handle.
-  @param[in, out] FilePath      On a sucessful return the device path to the 
handle.
+  @param[in, out] FilePath      On a successful return the device path to the 
handle.
 
-  @retval EFI_SUCCESS           The device path was sucessfully returned.
+  @retval EFI_SUCCESS           The device path was successfully returned.
   @retval other                 A error from gBS->HandleProtocol.
 
   @sa HandleProtocol
@@ -284,11 +284,11 @@ GetDevicePathForDriverHandle (
 }
 
 /**
-  Functino to get Device Path by a handle.
+  Function to get Device Path by a handle.
 
   @param[in]        TheHandle   Use it to get DevicePath.
   @param[in]        Target      Boot option target.
-  @param[in, out]   DevicePath  On a sucessful return the device path to the 
handle.
+  @param[in, out]   DevicePath  On a successful return the device path to the 
handle.
 
   @retval   SHELL_INVALID_PARAMETER The handle was NULL.
   @retval   SHELL_NOT_FOUND         Not found device path by handle.
@@ -870,7 +870,7 @@ BcfgAdd (
 }
 
 /**
-  Funciton to remove an item.
+  Function to remove an item.
 
   @param[in] Target         The target item to move.
   @param[in] CurrentOrder   The pointer to the current order of items.
@@ -934,7 +934,7 @@ BcfgRemove (
 }
 
 /**
-  Funciton to move a item to another location.
+  Function to move a item to another location.
 
   @param[in] Target         The target item to move.
   @param[in] CurrentOrder   The pointer to the current order of items.
@@ -1921,7 +1921,7 @@ ShellCommandGetManFileNameBcfg (
   @param[in] SystemTable    the EFI System Table pointer
   @param[in] Name           the profile name to use
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
diff --git a/ShellPkg/Library/UefiShellCommandLib/UefiShellCommandLib.c 
b/ShellPkg/Library/UefiShellCommandLib/UefiShellCommandLib.c
index 4549cbde9b9a..75fbd50cbe51 100644
--- a/ShellPkg/Library/UefiShellCommandLib/UefiShellCommandLib.c
+++ b/ShellPkg/Library/UefiShellCommandLib/UefiShellCommandLib.c
@@ -155,7 +155,7 @@ CommandInit (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS   the initialization was complete sucessfully
+  @retval EFI_SUCCESS   the initialization was complete successfully
 **/
 RETURN_STATUS
 EFIAPI
@@ -1286,7 +1286,7 @@ ShellCommandCreateNewMappingName (
   @param[in] Flags              The Flags attribute for this map item.
   @param[in] Path               TRUE to update path, FALSE to skip this step 
(should only be TRUE during initialization).
 
-  @retval EFI_SUCCESS           The addition was sucessful.
+  @retval EFI_SUCCESS           The addition was successful.
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed.
   @retval EFI_INVALID_PARAMETER A parameter was invalid.
 **/
@@ -1374,7 +1374,7 @@ ShellCommandAddMapItemAndUpdatePath (
 
   Also sets up the default path environment variable if Type is FileSystem.
 
-  @retval EFI_SUCCESS           All map names were created sucessfully.
+  @retval EFI_SUCCESS           All map names were created successfully.
   @retval EFI_NOT_FOUND         No protocols were found in the system.
   @return                       Error returned from gBS->LocateHandle().
 
diff --git a/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.c 
b/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.c
index c76805ed30a9..3dea3c2f2f45 100644
--- a/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.c
+++ b/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.c
@@ -1317,7 +1317,7 @@ Encode (
   @param[in, out]  DstSize       On input the size (in bytes) of DstBuffer, on
                                  return the number of bytes placed in 
DstBuffer.
 
-  @retval EFI_SUCCESS           The compression was sucessful.
+  @retval EFI_SUCCESS           The compression was successful.
   @retval EFI_BUFFER_TOO_SMALL  The buffer was too small.  DstSize is required.
 **/
 EFI_STATUS
diff --git a/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.h 
b/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.h
index dad3201c6053..37338ad4bd99 100644
--- a/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.h
+++ b/ShellPkg/Library/UefiShellDebug1CommandsLib/Compress.h
@@ -18,7 +18,7 @@
   @param[in, out]  DstSize       On input the size (in bytes) of DstBuffer, on
                                  return the number of bytes placed in 
DstBuffer.
 
-  @retval EFI_SUCCESS           The compression was sucessful.
+  @retval EFI_SUCCESS           The compression was successful.
   @retval EFI_BUFFER_TOO_SMALL  The buffer was too small.  DstSize is required.
 **/
 EFI_STATUS
diff --git 
a/ShellPkg/Library/UefiShellDebug1CommandsLib/UefiShellDebug1CommandsLib.c 
b/ShellPkg/Library/UefiShellDebug1CommandsLib/UefiShellDebug1CommandsLib.c
index c3682eeae476..a1a055928f3f 100644
--- a/ShellPkg/Library/UefiShellDebug1CommandsLib/UefiShellDebug1CommandsLib.c
+++ b/ShellPkg/Library/UefiShellDebug1CommandsLib/UefiShellDebug1CommandsLib.c
@@ -33,7 +33,7 @@ ShellCommandGetManFileNameDebug1 (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
diff --git 
a/ShellPkg/Library/UefiShellDriver1CommandsLib/UefiShellDriver1CommandsLib.c 
b/ShellPkg/Library/UefiShellDriver1CommandsLib/UefiShellDriver1CommandsLib.c
index d441f66e096f..28c4282659f4 100644
--- a/ShellPkg/Library/UefiShellDriver1CommandsLib/UefiShellDriver1CommandsLib.c
+++ b/ShellPkg/Library/UefiShellDriver1CommandsLib/UefiShellDriver1CommandsLib.c
@@ -32,7 +32,7 @@ ShellCommandGetManFileNameDriver1 (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
diff --git 
a/ShellPkg/Library/UefiShellInstall1CommandsLib/UefiShellInstall1CommandsLib.c 
b/ShellPkg/Library/UefiShellInstall1CommandsLib/UefiShellInstall1CommandsLib.c
index 16c2df338297..7745f3415f08 100644
--- 
a/ShellPkg/Library/UefiShellInstall1CommandsLib/UefiShellInstall1CommandsLib.c
+++ 
b/ShellPkg/Library/UefiShellInstall1CommandsLib/UefiShellInstall1CommandsLib.c
@@ -16,7 +16,7 @@
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
diff --git 
a/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.c 
b/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.c
index 92e438437fa4..503b74c86505 100644
--- a/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.c
+++ b/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.c
@@ -34,7 +34,7 @@ ShellCommandGetManFileNameLevel1 (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
@@ -243,7 +243,7 @@ TestNodeForMove (
   @param[in] MovePast          TRUE makes function return 1 past the found
                                location.
   @param[in] FindOnly          TRUE to not change the ScriptFile.
-  @param[in] WrapAroundScript  TRUE to wrap end-to-begining or vise versa in
+  @param[in] WrapAroundScript  TRUE to wrap end-to-beginning or vise versa in
                                searching.
 **/
 BOOLEAN
diff --git 
a/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.h 
b/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.h
index 45584cdb9616..6d3294ad04fd 100644
--- a/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.h
+++ b/ShellPkg/Library/UefiShellLevel1CommandsLib/UefiShellLevel1CommandsLib.h
@@ -183,7 +183,7 @@ LIST_ENTRY *
   @param[in] MovePast          TRUE makes function return 1 past the found
                                location.
   @param[in] FindOnly          TRUE to not change the ScriptFile.
-  @param[in] WrapAroundScript  TRUE to wrap end-to-begining or vise versa in
+  @param[in] WrapAroundScript  TRUE to wrap end-to-beginning or vise versa in
                                searching.
 **/
 BOOLEAN
diff --git a/ShellPkg/Library/UefiShellLevel2CommandsLib/Cd.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/Cd.c
index 48ef988fb744..88791c442866 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/Cd.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/Cd.c
@@ -14,8 +14,8 @@
 /**
   Function will replace drive identifier with CWD.
 
-  If FullPath begining with ':' is invalid path, then ASSERT.
-  If FullPath not include dirve identifier , then do nothing.
+  If FullPath beginning with ':' is invalid path, then ASSERT.
+  If FullPath not include drive identifier , then do nothing.
   If FullPath likes "fs0:\xx" or "fs0:/xx" , then do nothing.
   If FullPath likes "fs0:xxx" or "fs0:", the drive replaced by CWD.
 
diff --git a/ShellPkg/Library/UefiShellLevel2CommandsLib/Ls.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/Ls.c
index 6f9d035a1ae4..c03967ee3a2b 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/Ls.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/Ls.c
@@ -427,7 +427,7 @@ FileTimeToLocalTime (
   @param[in] ListUnfiltered TRUE to request listing the directory contents
                             unfiltered.
 
-  @retval SHELL_SUCCESS     the printing was sucessful.
+  @retval SHELL_SUCCESS     the printing was successful.
 **/
 SHELL_STATUS
 PrintLsOutput (
diff --git a/ShellPkg/Library/UefiShellLevel2CommandsLib/Map.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/Map.c
index f3c888edd48c..1e7168364d5f 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/Map.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/Map.c
@@ -1354,7 +1354,7 @@ ShellCommandRunMap (
                                 SName,
                                 TRUE
                                 );
-              } // we were sucessful so do an output
+              } // we were successful so do an output
             }
           } // got a valid map target
         } // got 2 variables
diff --git a/ShellPkg/Library/UefiShellLevel2CommandsLib/Set.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/Set.c
index c9082eb76ce6..79596373d6e3 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/Set.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/Set.c
@@ -14,7 +14,7 @@
 
   If you spawn a pre 2.0 shell from the Shell 2.0 the environment variable may 
not carry through.
 
-  @retval STATUS_SUCCESS  the printout was sucessful
+  @retval STATUS_SUCCESS  the printout was successful
   @return any return code from GetNextVariableName except EFI_NOT_FOUND
 **/
 SHELL_STATUS
diff --git 
a/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.c
index 794284d02ebe..ae643996aa72 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.c
@@ -53,7 +53,7 @@ ShellCommandGetManFileNameLevel2 (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
@@ -148,10 +148,10 @@ ShellLevel2CommandsLibDestructor (
 }
 
 /**
-  returns a fully qualified directory (contains a map drive at the begining)
+  returns a fully qualified directory (contains a map drive at the beginning)
   path from a unknown directory path.
 
-  If Path is already fully qualified this will return a duplicat otherwise this
+  If Path is already fully qualified this will return a duplicate otherwise 
this
   will use get the current directory and use that to build the fully qualified
   version.
 
@@ -161,7 +161,7 @@ ShellLevel2CommandsLibDestructor (
 
   @retval NULL            A memory allocation failed
   @retval NULL            A fully qualified path could not be discovered.
-  @retval other           An allocated pointer to a fuly qualified path.
+  @retval other           An allocated pointer to a fully qualified path.
 **/
 CHAR16 *
 GetFullyQualifiedPath (
diff --git 
a/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.h 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.h
index 7c525b31d056..814044d095d6 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.h
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/UefiShellLevel2CommandsLib.h
@@ -241,10 +241,10 @@ ShellCommandRunMv (
   );
 
 /**
-  returns a fully qualified directory (contains a map drive at the begining)
+  returns a fully qualified directory (contains a map drive at the beginning)
   path from a unknown directory path.
 
-  If Path is already fully qualified this will return a duplicat otherwise this
+  If Path is already fully qualified this will return a duplicate otherwise 
this
   will use get the current directory and use that to build the fully qualified
   version.
 
@@ -254,7 +254,7 @@ ShellCommandRunMv (
 
   @retval NULL            A memory allocation failed
   @retval NULL            a fully qualified path could not be discovered.
-  @retval other           pointer to a fuly qualified path.
+  @retval other           pointer to a fully qualified path.
 **/
 CHAR16 *
 GetFullyQualifiedPath (
diff --git a/ShellPkg/Library/UefiShellLevel2CommandsLib/Vol.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/Vol.c
index 8f7310c07474..c4accca6cdf0 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/Vol.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/Vol.c
@@ -18,7 +18,7 @@
   @param[in] Delete         TRUE to delete the volume label. FALSE otherwise.
   @param[in] Name           New name to set to the volume label.
 
-  @retval SHELL_SUCCESS     The operation was sucessful.
+  @retval SHELL_SUCCESS     The operation was successful.
 **/
 SHELL_STATUS
 HandleVol (
diff --git a/ShellPkg/Library/UefiShellLevel3CommandsLib/Alias.c 
b/ShellPkg/Library/UefiShellLevel3CommandsLib/Alias.c
index 5a8a21aac7b8..8ad0dd63ad19 100644
--- a/ShellPkg/Library/UefiShellLevel3CommandsLib/Alias.c
+++ b/ShellPkg/Library/UefiShellLevel3CommandsLib/Alias.c
@@ -17,7 +17,7 @@
   @param[in]  Alias             Points to the NULL-terminated shell alias.
                                 If this parameter is NULL, then all
                                 aliases will be returned in ReturnedData.
-  @retval     SHELL_SUCCESS     the printout was sucessful
+  @retval     SHELL_SUCCESS     the printout was successful
 **/
 SHELL_STATUS
 PrintSingleShellAlias (
@@ -47,7 +47,7 @@ PrintSingleShellAlias (
 /**
   Print out each alias registered with the Shell.
 
-  @retval STATUS_SUCCESS  the printout was sucessful
+  @retval STATUS_SUCCESS  the printout was successful
   @return any return code from GetNextVariableName except EFI_NOT_FOUND
 **/
 SHELL_STATUS
diff --git a/ShellPkg/Library/UefiShellLevel3CommandsLib/Touch.c 
b/ShellPkg/Library/UefiShellLevel3CommandsLib/Touch.c
index 823328155bfe..624641696777 100644
--- a/ShellPkg/Library/UefiShellLevel3CommandsLib/Touch.c
+++ b/ShellPkg/Library/UefiShellLevel3CommandsLib/Touch.c
@@ -232,8 +232,8 @@ ShellCommandRunTouch (
         }
 
         //
-        // make sure we completed the param parsing sucessfully...
-        // Also make sure that any previous action was sucessful
+        // make sure we completed the param parsing successfully...
+        // Also make sure that any previous action was successful
         //
         if (ShellStatus == SHELL_SUCCESS) {
           //
diff --git a/ShellPkg/Library/UefiShellLevel3CommandsLib/Type.c 
b/ShellPkg/Library/UefiShellLevel3CommandsLib/Type.c
index d00997d8189e..8e3138ad5b6a 100644
--- a/ShellPkg/Library/UefiShellLevel3CommandsLib/Type.c
+++ b/ShellPkg/Library/UefiShellLevel3CommandsLib/Type.c
@@ -251,8 +251,8 @@ ShellCommandRunType (
         }
 
         //
-        // make sure we completed the param parsing sucessfully...
-        // Also make sure that any previous action was sucessful
+        // make sure we completed the param parsing successfully...
+        // Also make sure that any previous action was successful
         //
         if (ShellStatus == SHELL_SUCCESS) {
           //
diff --git 
a/ShellPkg/Library/UefiShellLevel3CommandsLib/UefiShellLevel3CommandsLib.c 
b/ShellPkg/Library/UefiShellLevel3CommandsLib/UefiShellLevel3CommandsLib.c
index bef59b031cbb..35bb3803074a 100644
--- a/ShellPkg/Library/UefiShellLevel3CommandsLib/UefiShellLevel3CommandsLib.c
+++ b/ShellPkg/Library/UefiShellLevel3CommandsLib/UefiShellLevel3CommandsLib.c
@@ -33,7 +33,7 @@ ShellCommandGetManFileNameLevel3 (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS        the shell command handlers were installed 
sucessfully
+  @retval EFI_SUCCESS        the shell command handlers were installed 
successfully
   @retval EFI_UNSUPPORTED    the shell level required was not found.
 **/
 EFI_STATUS
diff --git a/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c 
b/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c
index 6a002b15e5f8..21e09db70df0 100644
--- a/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c
+++ b/ShellPkg/Library/UefiShellNetwork1CommandsLib/Ping.c
@@ -511,7 +511,7 @@ Ping6MatchEchoReply (
   The original intention is to send a request.
   Currently, the application retransmits an icmp6 echo request packet
   per second in sendnumber times that is specified by the user.
-  Because nothing can be done here, all things move to the timer rountine.
+  Because nothing can be done here, all things move to the timer routine.
 
   @param[in]    Event      A EFI_EVENT type event.
   @param[in]    Context    The pointer to Context.
diff --git 
a/ShellPkg/Library/UefiShellNetwork1CommandsLib/UefiShellNetwork1CommandsLib.c 
b/ShellPkg/Library/UefiShellNetwork1CommandsLib/UefiShellNetwork1CommandsLib.c
index c614c26c0c30..4d4bc2b4ab8d 100644
--- 
a/ShellPkg/Library/UefiShellNetwork1CommandsLib/UefiShellNetwork1CommandsLib.c
+++ 
b/ShellPkg/Library/UefiShellNetwork1CommandsLib/UefiShellNetwork1CommandsLib.c
@@ -32,7 +32,7 @@ ShellCommandGetManFileNameNetwork1 (
   @param ImageHandle            The image handle of the process.
   @param SystemTable            The EFI System Table pointer.
 
-  @retval EFI_SUCCESS           The shell command handlers were installed 
sucessfully.
+  @retval EFI_SUCCESS           The shell command handlers were installed 
successfully.
   @retval EFI_UNSUPPORTED       The shell level required was not found.
 **/
 EFI_STATUS
diff --git a/ShellPkg/Library/UefiShellNetwork2CommandsLib/Ping6.c 
b/ShellPkg/Library/UefiShellNetwork2CommandsLib/Ping6.c
index e0b58d4b8513..43d578bd6ad8 100644
--- a/ShellPkg/Library/UefiShellNetwork2CommandsLib/Ping6.c
+++ b/ShellPkg/Library/UefiShellNetwork2CommandsLib/Ping6.c
@@ -357,7 +357,7 @@ Ping6OnMatchEchoReply (
   The original intention is to send a request.
   Currently, the application retransmits an icmp6 echo request packet
   per second in sendnumber times that is specified by the user.
-  Because nothing can be done here, all things move to the timer rountine.
+  Because nothing can be done here, all things move to the timer routine.
 
   @param[in]    Event      A EFI_EVENT type event.
   @param[in]    Context    The pointer to Context.
diff --git a/ShellPkg/Library/UefiShellLevel2CommandsLib/Mv.c 
b/ShellPkg/Library/UefiShellLevel2CommandsLib/Mv.c
index 58cdeca7cb11..d93facc6f5d7 100644
--- a/ShellPkg/Library/UefiShellLevel2CommandsLib/Mv.c
+++ b/ShellPkg/Library/UefiShellLevel2CommandsLib/Mv.c
@@ -216,7 +216,7 @@ IsValidMove (
   that there is only a single possible target (IE we cant have wildcards that
   have 2 possible destination).
 
-  if the result is sucessful the caller must free *DestPathPointer.
+  if the result is successful the caller must free *DestPathPointer.
 
   @param[in] DestParameter               The original path to the destination.
   @param[in, out] DestPathPointer  A pointer to the callee allocated final 
path.
@@ -227,7 +227,7 @@ IsValidMove (
   @retval SHELL_INVALID_PARAMETER  The DestParameter could not be resolved to 
a location.
   @retval SHELL_INVALID_PARAMETER  The DestParameter could be resolved to more 
than 1 location.
   @retval SHELL_INVALID_PARAMETER  Cwd is required and is NULL.
-  @retval SHELL_SUCCESS            The operation was sucessful.
+  @retval SHELL_SUCCESS            The operation was successful.
 **/
 SHELL_STATUS
 GetDestinationLocation (
@@ -850,7 +850,7 @@ ShellCommandRunMv (
           } else {
             //
             // ValidateAndMoveFiles will report errors to the screen itself
             // Only change ShellStatus if it's sucessful
             //
             if (ShellStatus == SHELL_SUCCESS) {
               ShellStatus = ValidateAndMoveFiles (FileList, &Response, 
@@ -850,7 +850,7 @@ ShellCommandRunMv (
             //
             // ValidateAndMoveFiles will report errors to the screen itself
-            // Only change ShellStatus if it's sucessful
+            // Only change ShellStatus if it's successful
             //
             if (ShellStatus == SHELL_SUCCESS) {
ShellCommandLineGetRawValue (Package, ParamCount));
diff --git a/ShellPkg/Library/UefiShellLib/UefiShellLib.c 
b/ShellPkg/Library/UefiShellLib/UefiShellLib.c
index 746c9ccecee0..93e36197b26b 100644
--- a/ShellPkg/Library/UefiShellLib/UefiShellLib.c
+++ b/ShellPkg/Library/UefiShellLib/UefiShellLib.c
@@ -417,7 +417,7 @@ ShellLibConstructorWorker (
   @param ImageHandle    the image handle of the process
   @param SystemTable    the EFI System Table pointer
 
-  @retval EFI_SUCCESS   the initialization was complete sucessfully
+  @retval EFI_SUCCESS   the initialization was complete successfully
   @return others        an error ocurred during initialization
 **/
 EFI_STATUS
@@ -516,7 +516,7 @@ ShellLibDestructor (
 
 /**
   This function causes the shell library to initialize itself.  If the shell 
library
-  is already initialized it will de-initialize all the current protocol 
poitners and
+  is already initialized it will de-initialize all the current protocol 
pointers and
   re-populate them again.
 
   When the library is used with PcdShellLibAutoInitialize set to true this 
function
@@ -524,7 +524,7 @@ ShellLibDestructor (
 
   This function is intended for internal access for shell commands only.
 
-  @retval EFI_SUCCESS   the initialization was complete sucessfully
+  @retval EFI_SUCCESS   the initialization was complete successfully
 
 **/
 EFI_STATUS
@@ -962,7 +962,7 @@ ShellWriteFile (
 
 @param FileHandle               the file handle to close.
 
-@retval EFI_SUCCESS             the file handle was closed sucessfully.
+@retval EFI_SUCCESS             the file handle was closed successfully.
 **/
 EFI_STATUS
 EFIAPI
@@ -982,7 +982,7 @@ ShellCloseFile (
 
   @param FileHandle             the file handle to delete
 
-  @retval EFI_SUCCESS           the file was closed sucessfully
+  @retval EFI_SUCCESS           the file was closed successfully
   @retval EFI_WARN_DELETE_FAILURE the handle was closed, but the file was not
                                 deleted
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
@@ -1008,9 +1008,9 @@ ShellDeleteFile (
   has the effect of starting the read process of the directory entries over.
 
   @param FileHandle             The file handle on which the position is being 
set
-  @param Position               Byte position from begining of file
+  @param Position               Byte position from beginning of file
 
-  @retval EFI_SUCCESS           Operation completed sucessfully.
+  @retval EFI_SUCCESS           Operation completed successfully.
   @retval EFI_UNSUPPORTED       the seek request for non-zero is not valid on
                                 directories.
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
@@ -1034,9 +1034,9 @@ ShellSetFilePosition (
   if FileHandle is a directory.
 
   @param FileHandle             The open file handle on which to get the 
position.
-  @param Position               Byte position from begining of file.
+  @param Position               Byte position from beginning of file.
 
-  @retval EFI_SUCCESS           the operation completed sucessfully.
+  @retval EFI_SUCCESS           the operation completed successfully.
   @retval INVALID_PARAMETER     One of the parameters has an invalid value.
   @retval EFI_UNSUPPORTED       the request is not valid on directories.
 **/
@@ -1152,7 +1152,7 @@ ShellFindNextFile (
   @param FileHandle             file handle from which size is retrieved
   @param Size                   pointer to size
 
-  @retval EFI_SUCCESS           operation was completed sucessfully
+  @retval EFI_SUCCESS           operation was completed successfully
   @retval EFI_DEVICE_ERROR      cannot access the file
 **/
 EFI_STATUS
@@ -1254,7 +1254,7 @@ environment variable is created and assigned the 
specified value.
   @param EnvVal                 The Value of the environment variable
   @param Volatile               Indicates whether the variable is non-volatile 
(FALSE) or volatile (TRUE).
 
-  @retval EFI_SUCCESS           the operation was completed sucessfully
+  @retval EFI_SUCCESS           the operation was completed successfully
   @retval EFI_UNSUPPORTED       This operation is not allowed in pre UEFI 2.0 
Shell environments
 **/
 EFI_STATUS
@@ -1302,7 +1302,7 @@ ShellSetEnvironmentVariable (
                                   in the form "x=y".  If NULL, the current set 
is used.
   @param[out] Status              The status of the run command line.
 
-  @retval EFI_SUCCESS             The operation completed sucessfully.  Status
+  @retval EFI_SUCCESS             The operation completed successfully.  Status
                                   contains the status code returned.
   @retval EFI_INVALID_PARAMETER   A parameter contains an invalid value.
   @retval EFI_OUT_OF_RESOURCES    Out of resources.
@@ -1576,7 +1576,7 @@ InternalShellConvertFileListType (
     NewInfo->Info     = AllocateCopyPool ((UINTN)OldInfo->Info->Size, 
OldInfo->Info);
 
     //
     // make sure all the memory allocations were sucessful
     //
     if ((NULL == NewInfo->FullName) || (NewInfo->FileName == NULL) || 
(NewInfo->Info == NULL)) {
       //
@@ -1621,7 +1621,7 @@ InternalShellConvertFileListType (
   @param OpenMode               mode to open files with
   @param ListHead               head of linked list of results
 
-  @retval EFI_SUCCESS           the operation was sucessful and the list head
+  @retval EFI_SUCCESS           the operation was successful and the list head
                                 contains the list of opened files
   @return != EFI_SUCCESS        the operation failed
 
@@ -1748,7 +1748,7 @@ ShellOpenFileMetaArg (
 
   @param ListHead               the pointer to free.
 
-  @retval EFI_SUCCESS           the operation was sucessful.
+  @retval EFI_SUCCESS           the operation was successful.
 **/
 EFI_STATUS
 EFIAPI
@@ -2131,7 +2131,7 @@ InternalIsFlag (
   @param[in] Argc               Count of parameters in Argv
   @param[in] AlwaysAllowNumbers TRUE to allow numbers always, FALSE otherwise.
 
-  @retval EFI_SUCCESS           The operation completed sucessfully.
+  @retval EFI_SUCCESS           The operation completed successfully.
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed
   @retval EFI_INVALID_PARAMETER A parameter was invalid
   @retval EFI_VOLUME_CORRUPTED  the command line was corrupt.  an argument was
@@ -2371,7 +2371,7 @@ InternalCommandLineParse (
   @param[in] AutoPageBreak      Will automatically set PageBreakEnabled.
   @param[in] AlwaysAllowNumbers Will never fail for number based flags.
 
-  @retval EFI_SUCCESS           The operation completed sucessfully.
+  @retval EFI_SUCCESS           The operation completed successfully.
   @retval EFI_OUT_OF_RESOURCES  A memory allocation failed.
   @retval EFI_INVALID_PARAMETER A parameter was invalid.
   @retval EFI_VOLUME_CORRUPTED  The command line was corrupt.
@@ -2875,7 +2875,7 @@ ShellCopySearchAndReplace (
 
   @param[in] String       The string to print out.
 
-  @retval EFI_SUCCESS     The operation was sucessful.
+  @retval EFI_SUCCESS     The operation was successful.
   @retval !EFI_SUCCESS    The operation failed.
 **/
 EFI_STATUS
@@ -3515,7 +3515,7 @@ StrnCatGrow (
   @param Prompt                   Pointer to string prompt to use to request 
input.
   @param Response                 Pointer to Response which will be populated 
upon return.
 
-  @retval EFI_SUCCESS             The operation was sucessful.
+  @retval EFI_SUCCESS             The operation was successful.
   @retval EFI_UNSUPPORTED         The operation is not supported as requested.
   @retval EFI_INVALID_PARAMETER   A parameter was invalid.
   @return other                   The operation failed.
@@ -3801,7 +3801,7 @@ ShellPromptForResponse (
   @param[in] HiiFormatHandle    The format string Handle for getting from Hii.
   @param Response               Pointer to Response which will be populated 
upon return.
 
-  @retval EFI_SUCCESS the operation was sucessful.
+  @retval EFI_SUCCESS the operation was successful.
   @return other       the operation failed.
 
   @sa ShellPromptForResponse
@@ -1576,7 +1576,7 @@ InternalShellConvertFileListType (
 
     //
-    // make sure all the memory allocations were sucessful
+    // make sure all the memory allocations were successful
     //
     if ((NULL == NewInfo->FullName) || (NewInfo->FileName == NULL) || 
diff --git 
a/ShellPkg/Library/UefiShellNetwork2CommandsLib/UefiShellNetwork2CommandsLib.c 
b/ShellPkg/Library/UefiShellNetwork2CommandsLib/UefiShellNetwork2CommandsLib.c
index 29c82450b746..20445ca4af26 100644
--- 
a/ShellPkg/Library/UefiShellNetwork2CommandsLib/UefiShellNetwork2CommandsLib.c
+++ 
b/ShellPkg/Library/UefiShellNetwork2CommandsLib/UefiShellNetwork2CommandsLib.c
@@ -32,7 +32,7 @@ ShellCommandGetManFileNameNetwork2 (
   @param ImageHandle            The image handle of the process.
   @param SystemTable            The EFI System Table pointer.
 
-  @retval EFI_SUCCESS           The shell command handlers were installed 
sucessfully.
+  @retval EFI_SUCCESS           The shell command handlers were installed 
successfully.
   @retval EFI_UNSUPPORTED       The shell level required was not found.
 **/
 EFI_STATUS
-- 
2.39.3 (Apple Git-145)



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#110997): https://edk2.groups.io/g/devel/message/110997
Mute This Topic: https://groups.io/mt/102492744/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-


Reply via email to